@@ -12,7 +12,7 @@
  * @author Akinobu LEE
  * @date   Mon Mar  7 23:19:14 2005
  *
- * $Revision: 1.7 $
+ * $Revision: 1.11 $
  * 
  */
 /*
@@ -99,6 +99,7 @@ boolean dfa_look_around(NEXTWORD *nword, NODE *hypo, RecogProcess *r);
 
 /* search_bestfirst_main.c */
 void segment_set_last_nword(NODE *hypo, RecogProcess *r);
+void pass2_finalize_on_no_result(RecogProcess *r, boolean use_1pass_as_final);
 void wchmm_fbs(HTK_Param *param, RecogProcess *r, int cate_bgn, int cate_num);
 
 /* search_bestfirst_v?.c */
@@ -109,9 +110,9 @@ NODE *newnode(RecogProcess *r);
 void malloc_wordtrellis(RecogProcess *r);
 void free_wordtrellis(StackDecode *dwrk);
 void scan_word(NODE *now, HTK_Param *param, RecogProcess *r);
-void next_word(NODE *now, NODE *new, NEXTWORD *nword, HTK_Param *param, RecogProcess *r);
-void start_word(NODE *new, NEXTWORD *nword, HTK_Param *param, RecogProcess *r);
-void last_next_word(NODE *now, NODE *new, HTK_Param *param, RecogProcess *r);
+void next_word(NODE *now, NODE *newParam, NEXTWORD *nword, HTK_Param *param, RecogProcess *r);
+void start_word(NODE *newParam, NEXTWORD *nword, HTK_Param *param, RecogProcess *r);
+void last_next_word(NODE *now, NODE *newParam, HTK_Param *param, RecogProcess *r);
 
 /* wav2mfcc.c */
 boolean wav2mfcc(SP16 speech[], int speechlen, Recog *recog);
@@ -146,12 +147,13 @@ void realbeam_free(Recog *recog);
 int mfcc_go(Recog *recog, int (*ad_check)(Recog *));
 
 /* word_align.c */
-void word_align(WORD_ID *words, short wnum, HTK_Param *param, Sentence *s, RecogProcess *r);
-void phoneme_align(WORD_ID *words, short wnum, HTK_Param *param, Sentence *s, RecogProcess *r);
-void state_align(WORD_ID *words, short wnum, HTK_Param *param, Sentence *s, RecogProcess *r);
-void word_rev_align(WORD_ID *revwords, short wnum, HTK_Param *param, Sentence *s, RecogProcess *r);
-void phoneme_rev_align(WORD_ID *revwords, short wnum, HTK_Param *param, Sentence *s, RecogProcess *r);
-void state_rev_align(WORD_ID *revwords, short wnum, HTK_Param *param, Sentence *s, RecogProcess *r);
+void word_align(WORD_ID *words, short wnum, HTK_Param *param, SentenceAlign *align, RecogProcess *r);
+void phoneme_align(WORD_ID *words, short wnum, HTK_Param *param, SentenceAlign *align, RecogProcess *r);
+void state_align(WORD_ID *words, short wnum, HTK_Param *param, SentenceAlign *align, RecogProcess *r);
+void word_rev_align(WORD_ID *revwords, short wnum, HTK_Param *param, SentenceAlign *align, RecogProcess *r);
+void phoneme_rev_align(WORD_ID *revwords, short wnum, HTK_Param *param, SentenceAlign *align, RecogProcess *r);
+void state_rev_align(WORD_ID *revwords, short wnum, HTK_Param *param, SentenceAlign *align, RecogProcess *r);
+void do_alignment_all(RecogProcess *r, HTK_Param *param);
 
 /* m_usage.c */
 void opt_terminate();
@@ -243,6 +245,7 @@ int multigram_activate(int gid, PROCESS_LM *lm);
 int multigram_deactivate(int gid, PROCESS_LM *lm);
 boolean multigram_load_all_gramlist(PROCESS_LM *lm);
 int multigram_get_gram_from_category(int category, PROCESS_LM *lm);
+int multigram_get_gram_from_wid(WORD_ID wid, PROCESS_LM *lm);
 int multigram_get_all_num(PROCESS_LM *lm);
 void multigram_free_all(MULTIGRAM *root);
 
@@ -287,6 +290,8 @@ boolean callback_delete(Recog *recog, int id);
 
 /* recogmain.c */
 int adin_cut_callback_store_buffer(SP16 *now, int len, Recog *recog);
+SentenceAlign *result_align_new();
+void result_align_free(SentenceAlign *a);
 void result_sentence_malloc(RecogProcess *r, int num);
 void result_sentence_free(RecogProcess *r);
 void clear_result(RecogProcess *r);
