@@ -23,7 +23,7 @@
  * @author Akinobu Lee
  * @date   Fri Feb 16 13:42:28 2007
  *
- * $Revision: 1.2 $
+ * $Revision: 1.7 $
  * 
  */
 /*
@@ -209,6 +209,11 @@ typedef struct __jconf_am__ {
     char *ssload_filename;
   } frontend;
 
+  /**
+   * Plugin source ID when using plugin (gprune_method is GPRUNE_SEL_USER)
+   */
+  int gprune_plugin_source;
+
   /* pointer to next instance */
   struct __jconf_am__ *next;
 
@@ -736,6 +741,13 @@ typedef struct __jconf_search__ {
      * 
      */
     boolean start_inactive;
+    /**
+     * In case the 2nd pass search fails, this option specifies Julius
+     * to use the result of the previous 1st pass as final result.
+     * When this is TRUE, no RECOGFAIL occur.
+     * 
+     */
+    boolean fallback_pass1_flag;
     
   } sw;
 
@@ -755,11 +767,30 @@ typedef struct __Jconf__ {
    */
   struct {
 
+    /**
+     * Input source type. (waveform / mfc)
+     * 
+     */
+    int type;
+
     /**
      * Input source.
      * 
      */
     int speech_input;
+
+    /**
+     * Input device.
+     * 
+     */
+    int device;
+
+    /**
+     * id of the selected plug-in if using plugin
+     * 
+     */
+    int plugin_source;
+
     /**
      * Sampling frequency
      * 
@@ -985,8 +1016,30 @@ typedef struct __Jconf__ {
    */
   JCONF_AM *gmm;
 
+  /**
+   * Current option declaration mode while loading options
+   * 
+   */
+  short optsection;
+
+  /**
+   * Whether option sectioning ristriction should be applied or not
+   * 
+   */
+  boolean optsectioning;
+
+
 } Jconf;
 
+enum {
+  JCONF_OPT_DEFAULT,
+  JCONF_OPT_GLOBAL,
+  JCONF_OPT_AM,
+  JCONF_OPT_LM,
+  JCONF_OPT_SR,
+  SIZEOF_JCONF_OPT
+};
+
 #endif /* __J_JCONF_H__ */
 
 /*
