@@ -20,16 +20,19 @@ mv aaa julius-simple
 
 # update binaries
 cd julius
-sh ./support/build-all.sh
+sh ./support/build-all.sh --without-sndfile
 mv build/bin/* ../bin
 mv build/lib/* ../lib
 mv build/include/* ../include
 mv julius-simple/julius-simple.c ../julius-simple
+cd ..
 # normalize libsent/libjulius directory for julius-simple
 perl ./support/setprefix.pl .. bin/libsent-config > tmp
 mv tmp bin/libsent-config
+chmod +x bin/libsent-config
 perl ./support/setprefix.pl .. bin/libjulius-config > tmp
 mv tmp bin/libjulius-config
+chmod +x bin/libjulius-config
 
 # copy the documents
 cp -p julius/00readme.txt 00readme-julius.txt
