@@ -5,10 +5,10 @@ dir=`dirname $1`
 cp $1 doc/man/${base}.1
 
 if [ -f ${dir}/00readme.txt ]; then
-    cp ${dir}/00readme.txt doc/catman/${base}.txt
+    cp ${dir}/00readme.txt doc/txt/${base}.txt
 fi
 if [ -f ${dir}/00readme-${base}.txt ]; then
-    cp ${dir}/00readme-${base}.txt doc/catman/${base}.txt
+    cp ${dir}/00readme-${base}.txt doc/txt/${base}.txt
 fi
 
 echo $1
